<?php

namespace App\Events;

use App\Models\Appointment;
use App\Models\Conversation;
use Illuminate\Broadcasting\Channel;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Contracts\Broadcasting\ShouldBroadcastNow;
use Illuminate\Foundation\Events\Dispatchable;
use Illuminate\Queue\SerializesModels;

class AppointmentCreatedOrUpdatedEvent implements ShouldBroadcastNow
{
    use Dispatchable, InteractsWithSockets, SerializesModels;

    public Conversation $conversation;
    public Appointment $appointment;

    public function __construct(Conversation $conversation, Appointment $appointment)
    {
        $this->conversation = $conversation;
        $this->appointment = $appointment;
    }

    public function broadcastOn(): Channel
    {
        return new PrivateChannel('encrypted-conversation.' . $this->conversation->id);
    }

    public function broadcastAs()
    {
        return 'appointment.createdOrUpdated';
    }

    public function broadcastWith()
    {
        return [
            'updating_user_id' => auth()->user()->id
        ];
    }
}
