<?php

namespace App\Events;

use App\Models\Conversation;
use Illuminate\Broadcasting\Channel;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Contracts\Broadcasting\ShouldBroadcastNow;

class ConversationAssetDeletedEvent implements ShouldBroadcastNow
{
    public Conversation $conversation;
    public int $conversation_asset_id;
    public string $type;

    public function __construct(Conversation $conversation, int $conversation_asset_id, string $type = 'conversation_asset')
    {
        $this->conversation = $conversation;
        $this->conversation_asset_id = $conversation_asset_id;
        $this->type = $type;
    }

    public function broadcastOn(): Channel
    {
        return new PrivateChannel('encrypted-conversation.' . $this->conversation->id);
    }

    public function broadcastAs()
    {
        return 'conversationAsset.deleted';
    }

    public function broadcastWith()
    {
        return [
            'id' => $this->conversation_asset_id,
            'type' => $this->type,
            'updating_user_id' => auth()->user()->id
        ];
    }
}
