<?php

namespace App\Events;

use App\Models\ConversationAsset;
use Illuminate\Broadcasting\Channel;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Contracts\Broadcasting\ShouldBroadcastNow;
use Illuminate\Foundation\Events\Dispatchable;
use Illuminate\Queue\SerializesModels;

class ConversationAssetUpdatedEvent implements ShouldBroadcastNow
{
    use Dispatchable, InteractsWithSockets, SerializesModels;

    public ConversationAsset $conversation_asset;

    public function __construct(ConversationAsset $conversation_asset)
    {
        $this->conversation_asset = $conversation_asset;
    }

    public function broadcastOn(): Channel
    {
        return new PrivateChannel('encrypted-conversation.' . $this->conversation_asset->conversation_id);
    }

    public function broadcastAs()
    {
        return 'conversationAsset.updated';
    }

    public function broadcastWith()
    {
        return [
            'id' => $this->conversation_asset->id,
            'title' => $this->conversation_asset->title,
            'type' => $this->conversation_asset->type,
            'description' => $this->conversation_asset->description,
            'user_id' => $this->conversation_asset->user_id,
            'updating_user_id' => auth()->user()->id
        ];
    }
}
