<?php

namespace App\Events;

use App\Models\Conversation;
use Illuminate\Broadcasting\Channel;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Contracts\Broadcasting\ShouldBroadcastNow;
use Illuminate\Foundation\Events\Dispatchable;
use Illuminate\Queue\SerializesModels;

class ConversationMediaUpdatedEvent implements ShouldBroadcastNow
{
    use Dispatchable, InteractsWithSockets, SerializesModels;

    public Conversation $conversation;

    public function __construct(Conversation $conversation)
    {
        $this->conversation = $conversation;
    }

    public function broadcastOn(): Channel|PrivateChannel|array
    {
        return new PrivateChannel('encrypted-conversation.' . $this->conversation->id);
    }

    public function broadcastAs(): string
    {
        return 'conversationMedia.updated';
    }

    public function broadcastWith()
    {
        return [
            'conversation_id' => $this->conversation->id,
        ];
    }

}
