<?php

namespace App\Events;

use App\Models\Conversation;
use App\Models\KnowledgebaseArticle;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Contracts\Broadcasting\ShouldBroadcastNow;
use Illuminate\Foundation\Events\Dispatchable;
use Illuminate\Queue\SerializesModels;

class KnowledgebaseArticleCreatedEvent implements ShouldBroadcastNow
{
    use Dispatchable, InteractsWithSockets, SerializesModels;

    public Conversation $conversation;
    public KnowledgebaseArticle $knowledgebase_article;

    public function __construct(Conversation $conversation, KnowledgebaseArticle $knowledgebase_article)
    {
        $this->conversation = $conversation;
        $this->knowledgebase_article = $knowledgebase_article;
    }

    public function broadcastOn(): PrivateChannel
    {
        return new PrivateChannel('encrypted-conversation.' . $this->conversation->id);
    }

    public function broadcastAs()
    {
        return 'knowledgebaseArticle.new';
    }

    public function broadcastWith()
    {
        return [
            'id' => $this->knowledgebase_article->id,
            'title' => $this->knowledgebase_article->title,
            'updating_user_id' => auth()->user()->id
        ];
    }
}
