<?php

namespace App\Events;

use App\Models\Message;
use Illuminate\Broadcasting\Channel;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Contracts\Broadcasting\ShouldBroadcastNow;
use Illuminate\Foundation\Events\Dispatchable;
use Illuminate\Queue\SerializesModels;

class NewMessage implements ShouldBroadcastNow
{
    use Dispatchable, InteractsWithSockets, SerializesModels;

    public $message, $humans_time;

    /**
     * Create a new event instance.
     *
     * @return void
     */
    public function __construct(Message $message, $humans_time)
    {
        $this->message = $message;
        $this->humans_time = $humans_time;
    }

    /**
     * Get the channels the event should broadcast on.
     *
     * @return \Illuminate\Broadcasting\Channel|array
     */
    public function broadcastOn(): Channel|PrivateChannel|array
    {
        return new PrivateChannel('encrypted-conversation.' . $this->message->conversation->id);
    }

    public function broadcastAs(): string
    {
        return 'message.new';
    }

    public function broadcastWith()
    {
        return [
            'id' => $this->message->id,
            'message' => $this->message->message,
            'sender' => $this->message->sender->only(['id', 'first_name', 'last_name']),
            'type' => $this->message->type,
            'humans_time' => $this->humans_time,
        ];
    }

}
