<?php

namespace App\Events;

use App\Models\TimelineItem;
use Illuminate\Broadcasting\Channel;
use Illuminate\Broadcasting\InteractsWithSockets;
use Illuminate\Broadcasting\PrivateChannel;
use Illuminate\Contracts\Broadcasting\ShouldBroadcastNow;
use Illuminate\Foundation\Events\Dispatchable;
use Illuminate\Queue\SerializesModels;

class NewTimelineItemEvent implements ShouldBroadcastNow
{
    use Dispatchable, InteractsWithSockets, SerializesModels;

    public TimelineItem $timeline_item;

    public function __construct(TimelineItem $timeline_item)
    {
        $this->timeline_item = $timeline_item;
    }

    public function broadcastOn(): Channel
    {
        return new PrivateChannel('encrypted-conversation.' . $this->timeline_item->conversation->id);
    }

    public function broadcastAs()
    {
        return 'timelineItem.new';
    }

    public function broadcastWith()
    {
        
        return [
            'id' => $this->timeline_item->id,
            'conversation_asset_id' => $this->timeline_item->conversation_asset_id,
            'title' => $this->timeline_item->title,
            'description' => $this->timeline_item->description,
            'type' => $this->timeline_item->type,
            'date' => $this->timeline_item->date->format('Y'),
            'is_locked_by' => $this->timeline_item->is_locked_by,
        ];
    }
}
