<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\UpdateUserRequest;
use App\Models\Organization;
use App\Models\User;
use Spatie\Permission\Models\Role;

class UpdateUserController extends Controller
{
    public function update(UpdateUserRequest $request, Organization $organization, User $user)
    {

        abort_if($user->id != auth()->user()->id && $user->hasRole('client') && !auth()->user()->hasPermissionTo('edit_clients'), 403);
        abort_if($user->id != auth()->user()->id && ($user->hasRole('counselor') || $user->hasRole('organization-admin')) && !auth()->user()->hasPermissionTo('edit_all_users'), 403);

        $validated = collect($request->validated());

        $user_data = $validated->only(['id', 'first_name', 'last_name', 'email', 'phone_number', 'is_active', 'role_id', 'counselor_id'])->toArray();
        $user_meta = $validated->only(['street', 'city', 'zip_code', 'country', 'birthday', 'highest_education', 'job', 'marital_status', 'children', 'gender', 'goals', 'comments'])->toArray();


        if (!$user->roles->contains($user_data['role_id']) && auth()->user()->hasRole(['organization-admin', 'super-admin'])) {
            $role = Role::find($user_data['role_id']);
            $user->syncRoles($role);
        }
        unset($user_data['role_id']);

        if ($request->has('counselor_id') && $user_data['counselor_id'] != $user->counselor_id) {
            $user->counselor()->associate($user_data['counselor_id'])->save();
        }

        unset($user_data['counselor_id']);
        $user->update($user_data);

        if ($user->hasRole('client')) {
            $user->user_meta()->updateOrCreate(['user_id' => $user->id], $user_meta);
        }

        $route = $user->hasRole('client') ? 'organizations.clients.show' : 'organizations.employees.show';

        return redirect()->route($route, [$organization, $user])->with('success', 'Updated successfully');
    }
}
