<?php

namespace App\Http\Controllers;

use App\Http\Requests\UpdateCompetenceCardRequest;
use App\Models\CompetenceCard;
use App\Models\CompetenceCardCategory;
use App\Services\MediaService;
use Inertia\Inertia;

class CompetenceCardController extends Controller
{
    public function index()
    {
        return Inertia::render('Settings/CompetenceCards/Index', [
            'competence_cards' => CompetenceCard::with('competence_card_category')->get(),
            'competence_card_categories' => CompetenceCardCategory::withCount('competence_cards')->get(),
        ]);
    }

    public function edit(CompetenceCard $competenceCard)
    {
        $competenceCard->getMedia('competence-card-icon');

        return Inertia::render('Settings/CompetenceCards/EditCompetenceCard', [
            'competence_card' => $competenceCard->load('competence_card_category'),
            'competence_card_categories' => CompetenceCardCategory::all(),
        ]);
    }

    public function update(CompetenceCard $competenceCard, UpdateCompetenceCardRequest $request, MediaService $mediaService)
    {
        $validated = $request->validated();
        $competenceCard->update($validated);

        if (!empty($validated['media'])) {
            $mediaService->saveCompetenceCardIcon($competenceCard, $validated);
        }

        return redirect()->route('app.settings.competence_cards.index')->with('success', 'Competence card updated.');
    }

    public function destroy(CompetenceCard $competenceCard)
    {
        $competenceCard->delete();

        return redirect()->route('app.settings.competence_cards.index')->with('success', 'Competence card deleted.');
    }
}
