<?php

namespace App\Http\Controllers;

use App\Http\Requests\StoreConversationNoteRequest;
use App\Models\CompetenceCard;
use App\Models\Conversation;
use App\Models\ConversationNote;
use App\Models\Organization;
use Inertia\Inertia;

class ConversationNoteController extends Controller
{

    public function index(Organization $organization, Conversation $conversation)
    {
        $clients = $conversation
            ->clients()
            ->with('user_meta')
            ->get();

        return Inertia::render('ConversationNotes/Index', [
            'conversation' => $conversation,
            'conversation_notes' => $conversation
                ->conversation_notes()
                ->with('appointment')
                ->orderBy('created_at', 'desc')
                ->get(),
            'appointments' => $conversation
                ->appointments()
                ->orderBy('start', 'desc')
                ->get(),
            'clients' => $clients,
            'client_names' => $conversation
                ->clients
                ->pluck('full_name')
                ->join(', '),
            'competence_card_sets' => $conversation
                ->competence_card_sets()->orderBy('created_at', 'desc')->get(),
            'timelines' => $conversation
                ->timelines()->orderBy('created_at', 'desc')->get(),
            'competence_cards' => $conversation->competence_card_sets
                ? CompetenceCard::all()
                : null,
        ]);
    }

    public function store(StoreConversationNoteRequest $request, Organization $organization, Conversation $conversation)
    {
        $validated = $request->validated();
        $validated['conversation_id'] = $conversation->id;

        $conversation_note = ConversationNote::create($validated);

        return redirect()->back()->with('success', 'Note saved successfully');
    }

    public function update(StoreConversationNoteRequest $request, Organization $organization, Conversation $conversation, ConversationNote $conversationNote)
    {
        $conversationNote->update($request->validated());

        return redirect()->back()->with('success', 'Note saved successfully');
    }

    public function destroy(Organization $organization, Conversation $conversation, ConversationNote $conversationNote)
    {
        $conversationNote->delete();

        return redirect()->back()->with('success', 'Note deleted');
    }
}
