<?php

namespace App\Http\Controllers;

use App\Models\Appointment;
use App\Models\Conversation;
use App\Models\Organization;
use Illuminate\Support\Facades\Request;
use Inertia\Inertia;

class DashboardController extends Controller
{
    public function show()
    {
        $organization = auth()->user()->currentOrganization;

        abort_if(!$organization && !auth()->user()->hasRole('super-admin') && !$organization->users()->where('users.id', auth()->user()->id)->exists(), 403);

        /*if (auth()->user()->id === 1) {
            $organization_appointments = Appointment::query()
                ->orderBy('start')
                ->with(['organization:id,name'])
                ->get()
                ->groupBy('organization.name');
        }*/

        $appointments = Appointment::query()
            ->whereBelongsTo($organization)
            ->belongsToUser()
            ->select(['id', 'organization_id', 'conversation_id', 'static_title', 'type', 'location', 'description', 'start', 'end'])
            ->whereDate('start', '>=', now())
            ->orderBy('start')
            ->limit(5)
            ->with(['users:first_name,last_name,email,phone_number', 'conversation:id,uuid'])
            ->get();

        $conversations = Conversation::query()
            ->whereBelongsTo($organization)
            ->belongsToUser()
            ->select('id', 'uuid', 'description', 'organization_id', 'is_active')
            ->with('users:id,first_name,last_name,email,phone_number')
            ->orderBy('created_at', 'desc')
            ->limit(5)
            ->withCount(['appointments', 'users'])
            ->get();

        if (auth()->user()->hasRole('super-admin|organization-admin|counselor')) {
            $clients = auth()->user()->clients()
                ->isOrganizationMember($organization)
                ->isActive()
                ->select('id', 'first_name', 'last_name', 'email', 'phone_number', 'counselor_id')
                ->orderBy('first_name')
                ->limit(5)
                ->withCount('appointments')
                ->get();
        }

        if (auth()->user()->hasRole('client')) {
            $counselor = auth()->user()->counselor()
                ->isOrganizationMember($organization)
                ->select('id', 'first_name', 'last_name', 'email', 'phone_number')
                ->withCount('appointments')
                ->get();
        }

        return Inertia::render('Dashboard/Dashboard', [
            'organization' => $organization,
            'appointments' => $appointments,
            'conversations' => $conversations,
            'clients' => $clients ?? null,
            'counselor' => $counselor ?? null,
            'filters' => Request::only('search'),
        ]);
    }

    public function show_testroom(Organization $organization)
    {
        return Inertia::render('Conversations/JitsiTestroom', [
            'organization' => $organization,
        ]);
    }
}
