<?php

namespace App\Http\Controllers;

use App\Models\Organization;
use App\Models\User;
use App\Services\ClientService;
use App\Services\RoleService;
use Inertia\Inertia;

class EmployeeController extends Controller
{

    public function show(Organization $organization, User $user)
    {
        abort_if(!$user->hasAnyRole(['organization-admin', 'counselor']), 404);
        
        return Inertia::render('Employees/Show', [
            'user' => $user->load(['organizations:id,name', 'clients:id,first_name,last_name,email,phone_number']),
            'clients' => $user->clients()
                ->select('id', 'first_name', 'last_name', 'email', 'phone_number')
                ->paginate(5, ['*'], 'clients')
                ->withQueryString(),
            'conversations' => $user->conversations()
                ->select('conversations.id', 'conversations.uuid')
                ->paginate(5, ['*'], 'conversations')
                ->withQueryString(),
            'appointments' => $user->appointments()
                ->select('appointments.id', 'appointments.type', 'appointments.static_title', 'appointments.start')
                ->paginate(5, ['*'], 'appointments')
                ->withQueryString(),
        ]);
    }

    public function edit(Organization $organization, User $user, RoleService $roleService)
    {
        abort_if(!$user->hasAnyRole(['organization-admin', 'counselor']), 404);

        $roles = $roleService->getAvailableRolesForUser(auth()->user())
            ->filter(function ($role) {
                return $role['value'] !== 'client';
            });

        return Inertia::render('Employees/Edit', [
            'user' => $user->load(['organizations:id,name', 'clients:id,first_name,last_name,email,phone_number', 'conversations:id,uuid']),
            'roles' => $roles,
        ]);
    }

    public function destroy(Organization $organization, User $user, ClientService $clientService)
    {
        abort_if(!auth()->user()->hasPermissionTo('delete_users'), 403);

        $clientService->deleteClient($user);

        return redirect()->route('organizations.clients.index', $organization->id)->with('success', 'Client deleted successfully.');
    }

}
