<?php

namespace App\Http\Controllers;

use App\Http\Requests\StoreKnowledgebaseCategoryRequest;
use App\Models\KnowledgebaseCategory;
use App\Models\Organization;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Inertia\Inertia;

class KnowledgebaseCategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Inertia\Response
     */
    public function index(Organization $organization)
    {
        return Inertia::render('KnowledgebaseCategories/Index', [
            'knowledgebase_categories' => KnowledgebaseCategory::whereBelongsTo($organization)->withCount('articles')->get(),
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Organization $organization)
    {
        return Inertia::render('KnowledgebaseCategories/Create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Organization $organization, StoreKnowledgebaseCategoryRequest $request)
    {
        $knowledgebase_category = KnowledgebaseCategory::create($request->validated());

        $knowledgebase_category->organization()->associate($organization);
        $knowledgebase_category->save();

        return Redirect::route('organizations.knowledgebase_categories.index', ['organization' => $organization])->with('success', 'Category created.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Organization $organization, KnowledgebaseCategory $knowledgebaseCategory)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Inertia\Response
     */
    public function edit(Organization $organization, KnowledgebaseCategory $knowledgebaseCategory)
    {
        return Inertia::render('KnowledgebaseCategories/Edit', [
            'knowledgebase_category' => $knowledgebaseCategory,
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function update(Organization $organization, KnowledgebaseCategory $knowledgebaseCategory, StoreKnowledgebaseCategoryRequest $request)
    {
        $knowledgebaseCategory->update($request->validated());

        return Redirect::route('organizations.knowledgebase_categories.index', ['organization' => $organization])->with('success', 'Category updated.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy(Organization $organization, KnowledgebaseCategory $knowledgebaseCategory)
    {
        if ($knowledgebaseCategory) {
            $knowledgebaseCategory->delete();
            return Redirect::route('organizations.knowledgebase_categories.index', ['organization' => $organization->id])->with('success', 'Knowledgebase Category deleted.');
        }
    }
}
