<?php

namespace App\Http\Controllers;

use App\Models\Organization;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class MediaController extends Controller
{

    public function getUserMedia(Organization $organization, $mediaId, $fileName)
    {

        if (!Auth::check()) {
            abort(403);
        }

        $media = Media::find($mediaId);

        if (!$media) {
            abort(404);
        }

        // Media types: organization_media (only accessible to organization members), conversation_media (only accesibale to users in the conversation)
        $media_organization_id = $media->getCustomProperty('organization_id') ?? null;
        $media_type = $media->getCustomProperty('media_type') ?? 'organization_media';
        $media_user_id = $media->getCustomProperty('user_id') ?? null;
        $media_conversation_uuid = $media->getCustomProperty('conversation_uuid') ?? null;
        
        abort_if(!Auth::user()->organizations->pluck('id')->contains($media_organization_id) && !Auth::user()->hasRole('super-admin'), 403);
        abort_if($media_type == 'conversation_media' && !Auth::user()->conversations->pluck('uuid')->contains($media_conversation_uuid) && !Auth::user()->hasRole('super-admin'), 403);

        $path = "{$media->collection_name}/$mediaId/$fileName";

        if (!Storage::disk('user_media')->exists($path)) {
            abort(404);
        }

        return response()->file(Storage::disk('user_media')->path($path));

    }

}
