<?php

namespace App\Http\Controllers;

use App\Http\Requests\RegisterOrganizationRequest;
use App\Models\Organization;
use App\Models\User;
use App\Notifications\OrganizationCreatedAdminNotification;
use App\Services\OrganizationService;
use Illuminate\Auth\Events\Registered;
use Illuminate\Support\Facades\Hash;
use Inertia\Inertia;

class RegistrationController extends Controller
{

    public function __construct()
    {
        $this->organizationService = new OrganizationService();
    }


    public function store(RegisterOrganizationRequest $request)
    {
        $validate = $request->validated();

        $organization_keys = [
            'organization_name',
            'organization_phone_number',
            'organization_email',
            'website',
            'street',
            'city',
            'zip_code',
            'country'
        ];

        $organization_data = array_intersect_key($validate, array_flip($organization_keys));
        $organization_data = array_combine(array_map(function ($key) {
            return str_replace('organization_', '', $key);
        }, array_keys($organization_data)), $organization_data);
        $organization_data['is_active'] = true;

        $user_data = array_diff_key($validate, array_flip($organization_keys));
        $user_data['password'] = Hash::make($user_data['password']);

        $organization = Organization::create($organization_data);
        $user = User::create($user_data);

        $user->organizations()->attach($organization->id);
        $user->currentOrganization()->associate($organization->id);
        $user->syncRoles(['organization-admin']);

        $user->save();

        foreach ($this->organizationService->getDefaultKnowledgebaseCategoryTitlesByCountry($organization->country) as $category) {
            $organization->knowledgeBaseCategories()->create([
                'title' => $category,
                'is_active' => true
            ]);
        }

        $admin_users = User::role('super-admin')->get();
        if ($admin_users->isNotEmpty()) {
            foreach ($admin_users as $admin_user) {
                $admin_user->notify((new OrganizationCreatedAdminNotification($organization))->locale(app()->getLocale() ?? 'en'));
            }
        }

        try {
            event(new Registered($user));
        } catch (\Exception $e) {

        }

        auth()->login($user);

        return redirect()->route('organization.dashboard');

    }

    public function create()
    {
        return Inertia::render('Auth/RegisterOrganization');
    }
}
