<?php

namespace App\Http\Controllers;

use App\Events\DeleteTimelineItemEvent;
use App\Events\LockTimelineItemEvent;
use App\Events\NewTimelineItemEvent;
use App\Http\Requests\LockTimelineItemRequest;
use App\Http\Requests\StoreTimelineItemRequest;
use App\Models\Conversation;
use App\Models\ConversationAsset;
use App\Models\Organization;
use App\Models\TimelineItem;
use Illuminate\Support\Carbon;

class TimelineItemController extends Controller
{

    public function __construct()
    {
        $this->middleware('permission:view_conversation_assets|view_all_conversation_assets')->only(['index', 'show']);
        $this->middleware('permission:edit_conversation_assets|edit_all_conversation_assets')->only(['create', 'store', 'update']);
        $this->middleware(['permission:edit_conversation_assets|edit_all_conversation_assets'])->only(['destroy']);
    }

    public function store(Organization $organization, Conversation $conversation, ConversationAsset $conversation_asset, StoreTimelineItemRequest $request)
    {
        $validated = $request->validated();

        if (!empty($validated['date'])) {
            $validated['date'] = Carbon::createFromDate($validated['date'], 1, 1);
        }

        $timeline_item = $conversation_asset->timeline_items()->create($validated);

        broadcast(new NewTimelineItemEvent($timeline_item));

        return redirect()->back()->with('success', 'Timeline item created');

    }

    public function lock(Organization $organization, Conversation $conversation, ConversationAsset $conversation_asset, TimelineItem $timeline_item, LockTimelineItemRequest $request)
    {
        $validated = $request->validated();
        if (!empty($validated)) {
            $timeline_item->update($validated);
        } else {
            $timeline_item->update(['is_locked_by' => null]);
        }

        broadcast(new LockTimelineItemEvent($timeline_item));

        return redirect()->back();
    }

    public function update(Organization $organization, Conversation $conversation, ConversationAsset $conversation_asset, TimelineItem $timeline_item, StoreTimelineItemRequest $request)
    {
        $validated = $request->validated();
        if (!empty($validated['date'])) {
            $validated['date'] = Carbon::createFromDate($validated['date'], 1, 1);
        }

        $timeline_item->update($validated);

        broadcast(new NewTimelineItemEvent($timeline_item));

        return redirect(route('organizations.conversations.show', [$organization->id, $conversation->uuid, $conversation_asset->id]))->with('success', 'Asset updated successfully');
    }

    public function destroy(Organization $organization, Conversation $conversation, ConversationAsset $conversation_asset, TimelineItem $timeline_item)
    {

        $deleted_timeline_item = $timeline_item->toArray();
        $deleted_timeline_item['conversation_id'] = $timeline_item->conversation->id;

        $timeline_item->delete();
        broadcast(new DeleteTimelineItemEvent($deleted_timeline_item));

        return redirect()->back()->with('success', 'Timeline item deleted');
    }
}
