<?php

namespace App\Http\Middleware;

use Illuminate\Http\Request;
use Inertia\Middleware;

class HandleInertiaRequests extends Middleware
{
    /**
     * The root template that is loaded on the first page visit.
     *
     * @var string
     */
    protected $rootView = 'app';

    /**
     * Determine the current asset version.
     *
     * @param \Illuminate\Http\Request $request
     * @return string|null
     */
    public function version(Request $request)
    {
        return parent::version($request);
    }

    /**
     * Define the props that are shared by default.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function share(Request $request)
    {
        if (empty($request->session()->get('locale'))) {
            $request->session()->put('locale', 'en');
        }

        return array_merge(parent::share($request), [
            'auth' => [
                'user' => $request->user(),
                'organizations' => $request->user() ? $request->user()->organizations()->select('id', 'name')->get() : NULL,
                'conversations' => $request->user() ? $request->user()->conversations()->select('id', 'uuid', 'organization_id')->get() : NULL,
            ],
            'permissions' => json_decode(auth()->check() ? auth()->user()->jsPermissions() : '{}', true),
            'flash' => function () use ($request) {
                return [
                    'success' => $request->session()->get('success'),
                    'error' => $request->session()->get('error'),
                ];
            },
            'current_organization' => [
                'organization_id' => auth()->check() ? auth()->user()->currentOrganization->id : NULL,
                'organization_uuid' => auth()->check() ? auth()->user()->currentOrganization->uuid : NULL,
                'organization_name' => auth()->check() ? auth()->user()->currentOrganization->name : NULL,
            ],
            'locale' => $request->session()->get('locale'),
        ]);
    }
}
