<?php

namespace App\Http\Requests;

use App\Rules\CounselorOrganizationMemberRule;
use App\Rules\EncryptedEmailUniqueRule;
use Illuminate\Foundation\Http\FormRequest;

class InviteUserRequest extends FormRequest
{
    public function rules(): array
    {
        return [
            'first_name' => ['required', 'max:254', 'string', 'min:2'],
            'last_name' => ['required', 'max:254', 'string', 'min:2'],
            'email' => ['required', 'email', 'max:255', new EncryptedEmailUniqueRule($this->email)],
            'organization_id' => ['required', 'numeric', 'exists:organizations,id'],
            'counselor_id' => ['numeric', 'exists:App\Models\User,id', 'required', new CounselorOrganizationMemberRule($this->organization_id, $this->counselor_id)],
            'role' => ['required', 'string', 'max:255', 'in:counselor,client'],
            'send_email' => ['required', 'boolean'],
        ];
    }
}
