<?php

namespace App\Http\Requests;

use App\Rules\EncryptedEmailUniqueRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rules\Password;

class RegisterOrganizationRequest extends FormRequest
{
    public function rules(): array
    {
        return [
            'first_name' => ['required', 'string', 'max:255', 'min:2'],
            'last_name' => ['required', 'string', 'max:255', 'min:2'],
            'email' => ['required', 'email', 'max:255', new EncryptedEmailUniqueRule($this->email)],
            'phone_number' => ['nullable', 'string', 'max:255', 'min:3'],
            'password' => ['required', Password::defaults()],
            'organization_name' => ['required', 'string', 'max:200'],
            'organization_phone_number' => ['nullable', 'string', 'max:200'],
            'organization_email' => ['required', 'email', 'max:200'],
            'website' => ['nullable', 'url', 'max:200'],
            'street' => ['required', 'string', 'max:200'],
            'city' => ['required', 'string', 'max:200'],
            'zip_code' => ['required', 'string', 'max:200'],
            'country' => ['required', 'string', 'max:200'],
            'privacy_tos_accepted' => ['required', 'accepted'],
        ];
    }
}
