<?php

namespace App\Http\Requests;

use App\Rules\CounselorOrganizationMemberRule;
use App\Rules\EncryptedEmailUniqueRule;
use App\Rules\OrganizationIdUuidRule;
use App\Rules\UserCanInviteCounselorRule;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rules\Password;

class RegisterUserRequest extends FormRequest
{
    public function rules(): array
    {
        return [
            'first_name' => ['required', 'string', 'max:255', 'min:2'],
            'last_name' => ['required', 'string', 'max:255', 'min:2'],
            'email' => ['required', 'email', 'max:255', new EncryptedEmailUniqueRule($this->email)],
            'password' => ['required', Password::defaults()],
            'phone_number' => ['nullable', 'string', 'max:255', 'min:3'],
            'organization_id' => ['required', 'string', 'exists:organizations,id'],
            'organization_uuid' => ['required_with:organization_id', 'string', new OrganizationIdUuidRule($this)],
            'role' => ['required', 'string', 'max:255', 'in:counselor,client'],
            'counselor_id' => ['numeric', 'exists:App\Models\User,id', 'required', new CounselorOrganizationMemberRule($this->organization_id, $this->counselor_id), new UserCanInviteCounselorRule($this->counselor_id, $this->role)],
            'privacy_tos_accepted' => ['required', 'accepted'],
        ];
    }

    public function authorize(): bool
    {
        return true;
    }
}
