<?php

namespace App\Http\Requests;

use App\Rules\EncryptedEmailUniqueRule;
use App\Services\RoleService;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rules\Password;

class StoreUserRequest extends FormRequest
{
    public function rules(): array
    {
        $roleService = new RoleService();

        return [
            'first_name' => ['required', 'string', 'max:255', 'min:2'],
            'last_name' => ['required', 'string', 'max:255', 'min:2'],
            'email' => ['required', 'email', 'max:255', new EncryptedEmailUniqueRule($this->email)],
            'phone_number' => ['nullable', 'string', 'max:255'],
            'password' => ['required', 'string', 'min:12', 'max:255', Password::defaults()],
            'is_active' => ['required', 'boolean'],
            'counselor_id' => ['required_if:role_id,3', 'nullable', 'exists:users,id'],
            'role_id' => ['required', 'integer', 'exists:roles,id', 'in:' . $roleService->getAvailableRolesForUser(auth()->user())->pluck('id')->implode(',')],
        ];
    }
}
