<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Spatie\MediaLibraryPro\Rules\Concerns\ValidatesMedia;

class UpdateOrganizationRequest extends FormRequest
{

    use ValidatesMedia;

    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [
            'name' => ['required', 'string', 'max:200'],
            'media' => $this->validateSingleMedia()
                ->extension(['png', 'jpg', 'jpeg'])
                ->mime(['image/png', 'image/jpeg'])
                ->maxItemSizeInKb(3000),
            'phone_number' => ['nullable', 'string', 'max:200'],
            'email' => ['required', 'email', 'max:200'],
            'website' => ['nullable', 'url', 'max:200'],
            'street' => ['required', 'string', 'max:200'],
            'city' => ['required', 'string', 'max:200'],
            'zip_code' => ['required', 'string', 'max:200'],
            'country' => ['required', 'string', 'max:200'],
            'tax_id' => ['required', 'string', 'max:200'],
            'is_active' => ['required', 'boolean']
        ];
    }
}
