<?php

namespace App\Http\Requests;

use App\Rules\EncryptedEmailUniqueRule;
use App\Rules\RoleSwitchRule;
use Illuminate\Foundation\Http\FormRequest;

class UpdateUserRequest extends FormRequest
{
    public function rules(): array
    {

        return [
            'id' => ['required', 'exists:App\Models\User,id'],
            'first_name' => ['required', 'string', 'max:255', 'min:2'],
            'last_name' => ['required', 'string', 'max:255', 'min:2'],
            'email' => ['required', 'email', 'max:255', new EncryptedEmailUniqueRule($this->email, $this->id)],
            'phone_number' => ['nullable', 'string', 'max:255'],
            'counselor_id' => ['numeric', 'exists:App\Models\User,id', 'nullable'],
            'is_active' => ['required', 'boolean'],
            'role_id' => ['required', 'exists:Spatie\Permission\Models\Role,id', new RoleSwitchRule($this->request->all()['id'], $this->request->all()['role_id'])],
            'street' => ['nullable', 'string', 'max:255'],
            'city' => ['nullable', 'string', 'max:255'],
            'zip_code' => ['nullable', 'string', 'max:255'],
            'country' => ['nullable', 'string', 'max:255'],
            'birthday' => ['nullable', 'date'],
            'highest_education' => ['nullable', 'string', 'max:255'],
            'job' => ['nullable', 'string', 'max:255'],
            'marital_status' => ['nullable', 'string', 'in:single,partnership,married,divorced,widowed'],
            'children' => ['nullable', 'string', 'max:255'],
            'gender' => ['nullable', 'string', 'in:female,male,diverse'],
            'goals' => ['nullable', 'string', 'in:application_documents,further_education,job_search,orientation,re_entry,miscellaneous'],
            'comments' => ['nullable', 'string', 'max:10000'],
        ];
    }

    public function authorize(): bool
    {
        return true;
    }
}
