<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\Image\Manipulations;
use Spatie\MediaLibrary\HasMedia;
use Spatie\MediaLibrary\InteractsWithMedia;
use Spatie\MediaLibrary\MediaCollections\Models\Media;

class CompetenceCard extends Model implements HasMedia
{
    use SoftDeletes, InteractsWithMedia;

    public $appends = ['ModelRoutes'];
    protected $fillable = [
        'title',
        'description',
        'competence_card_category_id',
        'icon',
        'selected',
        'active'
    ];

    public function getModelRoutesAttribute()
    {
        if (!auth()->check()) return ['index', 'edit', 'destroy'];

        return [
            'index' => route('app.settings.competence_cards.index'),
            'edit' => route('app.settings.competence_cards.edit', [$this->id]),
            'destroy' => route('app.settings.competence_cards.destroy', [$this->id]),
        ];
    }

    public function registerMediaConversions(Media $media = null): void
    {
        $this
            ->addMediaConversion('preview')
            ->fit(Manipulations::FIT_CROP, 300, 300)
            ->nonQueued();
    }

    public function scopeIsActive(Builder $query): Builder
    {
        return $query->where('is_active', true);
    }

    public function competence_card_category(): BelongsTo
    {
        return $this->belongsTo(CompetenceCardCategory::class);
    }
}
