<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class CompetenceCardCategory extends Model
{
    use SoftDeletes;

    public $appends = ['ModelRoutes'];
    protected $fillable = [
        'title',
        'accent_color',
        'light_color',
    ];

    public function getModelRoutesAttribute()
    {
        if (!auth()->check()) return ['index', 'edit', 'destroy'];

        return [
            'index' => route('app.settings.competence_card_categories.index'),
            'edit' => route('app.settings.competence_card_categories.edit', [$this->id]),
            'destroy' => route('app.settings.competence_card_categories.destroy', [$this->id]),
        ];
    }

    public function scopeIsActive(Builder $query): Builder
    {
        return $query->where('is_active', true);
    }

    public function competence_cards(): HasMany
    {
        return $this->hasMany(CompetenceCard::class);
    }
}
