<?php

namespace App\Models;

use App\Traits\Tenantable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class ConversationAsset extends Model
{
    use Tenantable, SoftDeletes;

    protected $fillable = [
        'title',
        'description',
        'type',
        'competence_card_set'
    ];

    protected $casts = [
        'competence_card_set' => 'array',
    ];

    public function organization(): BelongsTo
    {
        return $this->belongsTo(Organization::class);
    }

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class);
    }

    public function conversation(): BelongsTo
    {
        return $this->belongsTo(Conversation::class);
    }

    public function timeline_items(): HasMany
    {
        return $this->hasMany(TimelineItem::class);
    }


}
