<?php

namespace App\Models;

use App\Traits\Tenantable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use ParagonIE\CipherSweet\BlindIndex;
use ParagonIE\CipherSweet\EncryptedRow;
use Spatie\LaravelCipherSweet\Concerns\UsesCipherSweet;
use Spatie\LaravelCipherSweet\Contracts\CipherSweetEncrypted;
use SpatiePermissionsToVueInertia\Traits\SpatiePermissionsToVue;

class ConversationNote extends Model implements CipherSweetEncrypted
{
    use SoftDeletes, SpatiePermissionsToVue, UsesCipherSweet, Tenantable;

    protected $fillable = [
        'title',
        'content',
        'conversation_id',
        'appointment_id',
        'user_id',
    ];

    public static function configureCipherSweet(EncryptedRow $encryptedRow): void
    {

        $encryptedRow
            ->addField('title')
            ->addBlindIndex('title', new BlindIndex('title_index'));

        $encryptedRow
            ->addField('content')
            ->addBlindIndex('content', new BlindIndex('content_index'));

    }

    public function conversation(): BelongsTo
    {
        return $this->belongsTo(Conversation::class);
    }

    public function appointment(): BelongsTo
    {
        return $this->belongsTo(Appointment::class);
    }

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class);
    }

    public function organization(): BelongsTo
    {
        return $this->belongsTo(Organization::class);
    }
}
