<?php

namespace App\Models;

use App\Traits\Tenantable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class KnowledgebaseCategory extends Model
{
    use HasFactory, SoftDeletes, Tenantable;

    public $appends = ['ModelRoutes'];
    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'organization_id',
        'title',
        'order',
    ];

    public function getModelRoutesAttribute()
    {
        if (!auth()->check()) return ['index', 'show', 'edit', 'destroy'];

        return [
            'index' => route('organizations.knowledgebase_categories.index', [auth()->user()->currentOrganization->id]),
            'show' => route('organizations.knowledgebase_categories.show', [auth()->user()->currentOrganization->id, $this->id]),
            'edit' => route('organizations.knowledgebase_categories.edit', [auth()->user()->currentOrganization->id, $this->id]),
            'destroy' => route('organizations.knowledgebase_categories.destroy', [auth()->user()->currentOrganization->id, $this->id]),
        ];
    }

    public function articles()
    {
        return $this->belongsToMany(KnowledgebaseArticle::class, 'knowledgebase_article_knowledgebase_category', 'category_id', 'article_id');
    }

    public function organization()
    {
        return $this->belongsTo(Organization::class);
    }

}
