<?php

namespace App\Models;

use App\Traits\Tenantable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use ParagonIE\CipherSweet\BlindIndex;
use ParagonIE\CipherSweet\EncryptedRow;
use Spatie\LaravelCipherSweet\Concerns\UsesCipherSweet;
use Spatie\LaravelCipherSweet\Contracts\CipherSweetEncrypted;

class Message extends Model implements CipherSweetEncrypted
{
    use HasFactory, SoftDeletes, Tenantable, UsesCipherSweet;

    protected $fillable = [
        'organization_id',
        'message',
        'is_seen',
        'type',
        'organization_id',
        'user_id',
        'conversation_id',
    ];

    protected $appends = ['humans_time'];

    public static function configureCipherSweet(EncryptedRow $encryptedRow): void
    {
        $encryptedRow
            ->addField('message')
            ->addBlindIndex('message', new BlindIndex('message_index'));

    }

    public function getHumansTimeAttribute()
    {
        $date = $this->created_at;
        $now = $date->now();

        return $date->format('d.m.Y') == $now->format('d.m.Y') ? $date->format("H:i") : $date->format("d.m.Y @ H:i");
    }

    public function organization(): BelongsTo
    {
        return $this->belongsTo(Organization::class);
    }

    public function sender(): BelongsTo
    {
        return $this->belongsTo(User::class, 'user_id', 'id');
    }

    public function conversation(): BelongsTo
    {
        return $this->belongsTo(Conversation::class);
    }
}
