<?php

namespace App\Models;

use App\Traits\Tenantable;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Carbon;
use Znck\Eloquent\Relations\BelongsToThrough;

class TimelineItem extends Model
{
    use \Znck\Eloquent\Traits\BelongsToThrough, Tenantable, SoftDeletes;

    protected $fillable = [
        'title',
        'description',
        'date',
        'type',
        'is_locked_by',
    ];

    /*public function getDateAttribute($value)
    {
        return Carbon::parse($value)->format('Y');
    }*/

    public function organization(): BelongsTo
    {
        return $this->belongsTo(Organization::class);
    }

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class);
    }

    public function lockedBy(): BelongsTo
    {
        return $this->belongsTo(User::class, 'locked_by');
    }

    public function conversation_asset(): BelongsTo
    {
        return $this->belongsTo(ConversationAsset::class);
    }

    public function conversation(): BelongsToThrough
    {
        return $this->belongsToThrough(Conversation::class, ConversationAsset::class);
    }


}
