<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;
use ParagonIE\CipherSweet\BlindIndex;
use ParagonIE\CipherSweet\EncryptedRow;
use Spatie\LaravelCipherSweet\Concerns\UsesCipherSweet;
use Spatie\LaravelCipherSweet\Contracts\CipherSweetEncrypted;
use SpatiePermissionsToVueInertia\Traits\SpatiePermissionsToVue;

class UserMeta extends Model implements CipherSweetEncrypted
{
    use SoftDeletes, SpatiePermissionsToVue, UsesCipherSweet;

    protected $fillable = [
        'street',
        'zip_code',
        'city',
        'country',
        'birthday',
        'highest_education',
        'job',
        'marital_status',
        'children',
        'gender',
        'goals',
        'comments',
    ];

    public static function configureCipherSweet(EncryptedRow $encryptedRow): void
    {

        $encryptedRow
            ->addField('street')
            ->addBlindIndex('street', new BlindIndex('street_index'));

        $encryptedRow
            ->addField('zip_code')
            ->addBlindIndex('zip_code', new BlindIndex('zip_code_index'));

        $encryptedRow
            ->addField('city')
            ->addBlindIndex('city', new BlindIndex('city_index'));

        $encryptedRow
            ->addField('country')
            ->addBlindIndex('country', new BlindIndex('country_index'));

        $encryptedRow
            ->addField('birthday')
            ->addBlindIndex('birthday', new BlindIndex('birthday_index'));

        $encryptedRow
            ->addField('highest_education')
            ->addBlindIndex('highest_education', new BlindIndex('highest_education_index'));

        $encryptedRow
            ->addField('job')
            ->addBlindIndex('job', new BlindIndex('job_index'));

        $encryptedRow
            ->addField('marital_status')
            ->addBlindIndex('marital_status', new BlindIndex('marital_status_index'));

        $encryptedRow
            ->addField('children')
            ->addBlindIndex('children', new BlindIndex('children_index'));

        $encryptedRow
            ->addField('gender')
            ->addBlindIndex('gender', new BlindIndex('gender_index'));

        $encryptedRow
            ->addField('goals')
            ->addBlindIndex('goals', new BlindIndex('goals_index'));

        $encryptedRow
            ->addField('comments')
            ->addBlindIndex('comments', new BlindIndex('comments_index'));

    }

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class);
    }
}
