<?php

namespace App\Notifications;

use App\Models\Organization;
use Carbon\Carbon;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class AppointmentDeletedNotification extends Notification implements ShouldQueue
{
    protected array $appointment;
    protected Organization $organization;
    protected array $recipient;
    protected array $counselor;

    public function __construct($appointment, $organization, $recipient, $counselor)
    {
        $this->appointment = $appointment;
        $this->organization = $organization;
        $this->recipient = $recipient;
        $this->counselor = $counselor;
    }

    public function via($notifiable): array
    {
        return ['mail'];
    }

    public function toMail($notifiable): MailMessage
    {
        $url = url(route('organizations.appointments.index', [$this->organization->id]));

        return (new MailMessage)
            ->subject(__('Your counselling appointment has been terminated: :date', ['date' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment['start'])->format('d.m.Y')]))
            ->greeting(__('Hello :recipient!', ['recipient' => $this->recipient['first_name'] . ' ' . $this->recipient['last_name']]))
            ->line(__(':counselor has terminated the following appointment.', ['counselor' => $this->counselor['first_name'] . ' ' . $this->counselor['last_name']]))
            ->line(__('Date: :date', ['date' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment['start'])->format('d.m.Y')]))
            ->line(__('Time: :from – :to', ['from' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment['start'])->format('H:i'), 'to' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment['end'])->format('H:i')]))
            ->action(__('Open appointments overview'), $url)
            ->line(__('If you have any questions, please contact your counselor directly (:email).', ['email' => $this->counselor['email']]));
    }

    public function toArray($notifiable): array
    {
        return [];
    }
}
