<?php

namespace App\Notifications;

use App\Models\Appointment;
use App\Models\Organization;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class AppointmentUpdatedNotification extends Notification implements ShouldQueue
{
    use Queueable;

    protected Appointment $appointment;
    protected string $invite_url;
    protected Organization $organization;
    protected User $recipient;
    protected User $counselor;

    public function __construct($appointment, $organization, $recipient, $counselor)
    {
        $this->appointment = $appointment;
        $this->organization = $organization;
        $this->recipient = $recipient;
        $this->counselor = $counselor;
    }

    public function via($notifiable): array
    {
        return ['mail'];
    }

    public function toMail($notifiable): MailMessage
    {
        $url = url(route('organizations.appointments.index', [$this->organization->id]));

        return (new MailMessage)
            ->subject(__('Your counselling appointment has been updated: :date', ['date' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment->start)->format('d.m.Y')]))
            ->greeting(__('Hello :recipient!', ['recipient' => $this->recipient->first_name . ' ' . $this->recipient->last_name]))
            ->line(__(':counselor updated the counselling appointment with you.', ['counselor' => $this->counselor->first_name . ' ' . $this->counselor->last_name]))
            ->line(__('Date: :date', ['date' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment->start)->format('d.m.Y')]))
            ->line(__('Time: :from – :to', ['from' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment->start)->format('H:i'), 'to' => Carbon::createFromFormat('Y-m-d H:i:s', $this->appointment->end)->format('H:i')]))
            ->action(__('Open appointments overview'), $url)
            ->line(__('If you can not attend the appointment, please contact your counselor directly (:email).', ['email' => $this->counselor->email]));
    }

    public function toArray($notifiable): array
    {
        return [];
    }
}
