<?php

namespace App\Notifications;

use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class CounselorClientRegisteredNotification extends Notification implements ShouldQueue
{
    use Queueable;

    protected User $recipient;
    protected User $client;

    public function __construct($recipient, $client)
    {
        $this->recipient = $recipient;
        $this->client = $client;
    }

    public function via($notifiable): array
    {
        return ['mail'];
    }

    public function toMail($notifiable): MailMessage
    {
        $url = $this->client->currentOrganization->id == $this->recipient->currentOrganization->id
            ? route('organizations.clients.show', [$this->client->currentOrganization->id, $this->client->id])
            : route('organization.dashboard');

        return (new MailMessage)
            ->subject(__('Your client :client has registered on the OCCAY platform!', ['client' => $this->client->first_name . ' ' . $this->client->last_name]))
            ->greeting(__('Hello :recipient!', ['recipient' => $this->recipient['first_name'] . ' ' . $this->recipient['last_name']]))
            ->line(__('Your client :client has successfully created his/her account on the OCCAY platform.', ['client' => $this->client->first_name . ' ' . $this->client->last_name]))
            ->line(__('Create counselling appointments with your client and start counselling him/her.'))
            ->action(__('Open profile'), url($url));
    }

    public function toArray($notifiable): array
    {
        return [];
    }
}
