<?php

namespace App\Notifications;

use App\Models\Organization;
use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class InviteEmployeeNotification extends Notification implements ShouldQueue
{
    use Queueable;

    protected array $validated;
    protected string $invite_url;
    protected Organization $organization;
    protected User $counselor;

    public function __construct($validated, $invite_url, $organization, $counselor)
    {
        $this->validated = $validated;
        $this->invite_url = $invite_url;
        $this->organization = $organization;
        $this->counselor = $counselor;
    }

    public function via($notifiable): array
    {
        return ['mail'];
    }

    public function toMail($notifiable): MailMessage
    {

        return (new MailMessage)
            ->subject(__('Join :organization on OCCAY platform!', ['organization' => $this->organization->name]))
            ->greeting(__('Hello :recipient!', ['recipient' => $this->validated['first_name'] . ' ' . $this->validated['last_name']]))
            ->line(__('You have been invited to join your organization on the OCCAY online career counselling platform by :counselor.', ['counselor' => $this->counselor->first_name . ' ' . $this->counselor->last_name]))
            ->action(__('Accept invite and create account'), $this->invite_url)
            ->line(__('If you did not request to join :organization, no further action is required.', ['organization' => $this->organization->name]))
            ->line(__('This invitation will expire in 7 days (:date).', ['date' => now()->addDays(7)->format('d-m-Y')]));
    }

    public function toArray($notifiable): array
    {
        return [];
    }
}
