<?php

namespace App\Notifications;

use App\Models\Organization;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class OrganizationCreatedAdminNotification extends Notification implements ShouldQueue
{
    use Queueable;

    protected Organization $organization;

    public function __construct(Organization $organization)
    {
        $this->organization = $organization;
    }

    public function via($notifiable): array
    {
        return ['mail'];
    }

    public function toMail($notifiable): MailMessage
    {

        return (new MailMessage)
            ->subject(__('A new organization has registered to OCCAY'))
            ->greeting(__(':name has registered!', ['name' => $this->organization['name']]))
            ->line(__('A new organization has registered to the OCCAY platform:'))
            ->line(__('Name: :name', ['name' => $this->organization['name']]))
            ->line(__('Country: :country', ['country' => $this->organization['country']]))
            ->line(__('Email: :email', ['email' => $this->organization['email']]))
            ->line(__('Website: :website', ['website' => $this->organization['website']]));
    }

    public function toArray($notifiable): array
    {
        return [];
    }
}
