<?php

namespace App\Notifications;

use App\Models\Organization;
use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class UserCreatedAdminNotification extends Notification implements ShouldQueue
{
    use Queueable;

    protected User $user;
    protected Organization $organization;
    protected string $role_name;

    public function __construct(User $user, Organization $organization, string $role_name = '')
    {
        $this->user = $user;
        $this->organization = $organization;
        $this->role_name = $role_name;
    }

    public function via($notifiable): array
    {
        return ['mail'];
    }

    public function toMail($notifiable): MailMessage
    {
        return (new MailMessage)
            ->subject(__('A new user has registered to OCCAY'))
            ->greeting(__('New user registration for :name!', ['name' => $this->organization['name']]))
            ->line(__('Name: :name', ['name' => $this->user['full_name']]))
            ->line(__('Role: :role', ['role' => $this->role_name]));
    }

    public function toArray($notifiable): array
    {
        return [];
    }
}
