<?php

namespace App\Notifications;

use App\Models\Organization;
use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class UserCredentialsNotification extends Notification implements ShouldQueue
{
    use Queueable;

    protected User $user;
    protected Organization $organization;
    protected User $counselor;
    protected string $password;

    public function __construct($user, $organization, $counselor, $password)
    {
        $this->user = $user;
        $this->organization = $organization;
        $this->counselor = $counselor;
        $this->password = $password;
    }

    public function via($notifiable): array
    {
        return ['mail'];
    }

    public function toMail($notifiable): MailMessage
    {

        return (new MailMessage)
            ->subject(__('Your account credentials to join :organization on OCCAY', ['organization' => $this->organization->name]))
            ->greeting(__('Hello :recipient!', ['recipient' => $this->user['first_name'] . ' ' . $this->user['last_name']]))
            ->line(__(':counselor created an account for you on OCCAY - the educational and career guidance platform.', ['counselor' => $this->counselor->first_name . ' ' . $this->counselor->last_name]))
            ->line(__('Username: :email', ['email' => $this->user['email']]))
            ->line(__('Password: :password', ['password' => $this->password]))
            ->action(__('Sign in'), url(route('login')));
    }

    public function toArray($notifiable): array
    {
        return [];
    }
}
