<?php

namespace App\Observers;

use App\Models\User;

class UserObserver
{

    public function creating(User $user)
    {
        $user->privacy_tos_accepted = now();
    }

    public function updating(User $user)
    {

        if ($user->isDirty('is_active')) {
            $user->conversations()->update(['is_active' => $user->is_active]);
        }

        if ($user->isDirty('counselor_id')) {
            $old_counselor = User::find($user->getOriginal('counselor_id'));
            $new_counselor = User::find($user->counselor_id);

            abort_if(!$new_counselor || (!$new_counselor->hasRole('counselor') && !$new_counselor->hasRole('organization-admin') && !$new_counselor->hasRole('super-admin')),
                403,
                'Counselor not found or not a counselor');

            if ($user->conversations) {
                $conversations = $old_counselor
                    ? $user->conversations()->whereHas('users', function ($query) use ($old_counselor) {
                        $query->where('user_id', $old_counselor->id);
                    })->get()
                    : $user->conversations()->get();

                foreach ($conversations as $conversation) {
                    if ($old_counselor) {
                        $conversation->users()->detach($old_counselor->id);

                    }
                    $conversation->users()->attach($new_counselor->id);
                    $conversation->save();
                }
            }

            if ($user->appointments) {
                $appointments = $old_counselor
                    ? $user->appointments()->whereHas('users', function ($query) use ($old_counselor) {
                        $query->where('user_id', $old_counselor->id);
                    })->get()
                    : $user->appointments()->get();

                foreach ($appointments as $appointment) {
                    if ($old_counselor) {
                        $appointment->users()->detach($old_counselor->id);
                    }
                    $appointment->users()->attach($new_counselor->id);
                    $appointment->save();
                }
            }


        }
    }
}
