<?php

namespace App\Providers;

use App\Events\ClientRegisteredEvent;
use App\Events\UserCreatedEvent;
use App\Listeners\ClientRegisteredListener;
use App\Listeners\NewMessageListener;
use App\Listeners\UserCreatedListener;
use App\Models\Conversation;
use App\Models\ConversationAsset;
use App\Models\ConversationNote;
use App\Models\TimelineItem;
use App\Models\User;
use App\Observers\ConversationAssetObserver;
use App\Observers\ConversationNoteObserver;
use App\Observers\ConversationObserver;
use App\Observers\MessageObserver;
use App\Observers\TimelineItemObserver;
use App\Observers\UserObserver;
use Illuminate\Auth\Events\Registered;
use Illuminate\Auth\Listeners\SendEmailVerificationNotification;
use Illuminate\Foundation\Support\Providers\EventServiceProvider as ServiceProvider;

class EventServiceProvider extends ServiceProvider
{
    /**
     * The event listener mappings for the application.
     *
     * @var array
     */
    protected $listen = [
        Registered::class => [
            SendEmailVerificationNotification::class,
        ],

        ClientRegisteredEvent::class => [
            ClientRegisteredListener::class,
        ],

        UserCreatedEvent::class => [
            UserCreatedListener::class,
        ],
    ];

    /**
     * Register any events for your application.
     *
     * @return void
     */
    public function boot()
    {
        User::observe(UserObserver::class);
        Conversation::observe(ConversationObserver::class);
        ConversationAsset::observe(ConversationAssetObserver::class);
        ConversationNote::observe(ConversationNoteObserver::class);
        TimelineItem::observe(TimelineItemObserver::class);
    }
}
