<?php

namespace App\Rules;

use App\Models\User;
use Illuminate\Contracts\Validation\Rule;

class CounselorOrganizationMemberRule implements Rule
{
    protected $organization_id;
    protected $counselor_id;

    public function __construct($organization_id, $counselor_id)
    {
        $this->organization_id = $organization_id;
        $this->counselor_id = $counselor_id;
    }

    public function passes($attribute, $value): bool
    {
        $counselor = User::find($this->counselor_id);
        if (!$counselor) return false;
        if ($counselor->hasRole('super-admin')) return true;

        return $counselor->organizations->contains($this->organization_id);
    }

    public function message(): string
    {
        return 'The counselor is not part of the organization he/she invited you to join.';
    }
}
