<?php

namespace App\Rules;

use App\Models\User;
use Illuminate\Contracts\Validation\Rule;

class EncryptedEmailUniqueRule implements Rule
{
    protected $email;
    protected $user_id;

    public function __construct($email, $user_id = null)
    {
        $this->email = $email;
        $this->user_id = $user_id;
    }

    public function passes($attribute, $value): bool
    {
        $existing_user = User::withTrashed()->whereBlind('email', 'email_index', $this->email)->get()->first();

        // Creating new user
        if (!$this->user_id) {
            return !$existing_user;
        }

        // Updating existing user
        if ($existing_user && $existing_user->email == $this->email && $existing_user->id == $this->user_id) {
            return true;
        }

        if (!$existing_user) {
            return true;
        }

        return false;

    }

    public function message(): string
    {
        return 'This email address is already taken.';
    }
}
