<?php

namespace App\Rules;

use App\Models\User;
use Illuminate\Contracts\Validation\Rule;
use Spatie\Permission\Models\Role;

class RoleSwitchRule implements Rule
{
    protected int $user_id;
    protected int $role_id;

    public function __construct($user_id, $role_id)
    {
        $this->user_id = $user_id;
        $this->role_id = $role_id;
    }

    public function passes($attribute, $value): bool
    {
        $user = User::find($this->user_id);
        $role = Role::find($this->role_id);

        if (!$user || !$role) {
            return false;
        }

        if ($user->hasRole('client') && ($role->name == 'counselor' || $role->name == 'organization-admin')) {
            return false;
        }

        if (($user->hasRole('counselor') || $user->hasRole('organization-admin')) && $role->name == 'client') {
            return false;
        }

        return true;
    }

    public function message(): string
    {
        return 'The role you selected is not assignable to this user.';
    }
}
