<?php

namespace App\Rules;

use App\Models\User;
use Illuminate\Contracts\Validation\Rule;

class UserCanInviteCounselorRule implements Rule
{
    protected $counselor_id;
    protected $role;

    public function __construct($counselor_id, $role)
    {
        $this->counselor_id = $counselor_id;
        $this->role = $role;
    }

    public function passes($attribute, $value): bool
    {
        $counselor = User::find($this->counselor_id);

        if (!$counselor) return false;

        if ($counselor->hasRole('super-admin')) return true;

        if ($this->role !== 'client' && $counselor->hasRole('organization-admin')) return true;

        return $counselor->hasAnyRole(['organization-admin', 'counselor']);
    }

    public function message(): string
    {
        return 'This user can not invite counselors to an organization.';
    }
}
