<?php

namespace App\Services;

use App\Models\Conversation;

class ClientService
{
    public function createConversation($client, $counselor): Conversation
    {
        if ($this->hasConversation($client, $counselor)) {
            return $client->conversations->where('counselor_id', $counselor->id)->first();
        }

        $conversation = $client->conversations()->create();
        $conversation->organization()->associate($client->currentOrganization);
        $conversation->users()->attach($counselor);
        $conversation->save();

        $client->counselor()->associate($counselor->id);
        $client->saveQuietly();

        return $conversation;

    }

    // create a conversation between a client and a counselor

    public function hasConversation($client, $counselor): bool
    {
        return $client->conversations->contains('counselor_id', $counselor->id);
    }

    // delete client with associated data

    public function deleteClient($client)
    {
        $client->appointments()->delete();
        $conversations = $client->conversations;

        if ($conversations) {
            foreach ($conversations as $conversation) {
                $conversation->messages()->delete();
                $conversation->timeline_items()->delete();
                $conversation->conversation_assets()->delete();
            }

            $client->conversations()->delete();
        }
        $client->organizations()->detach();
        $client->forceDelete();
    }


}
