<?php

namespace App\Services;

use App\Models\User;
use App\Rules\EncryptedEmailUniqueRule;
use Illuminate\Support\Facades\URL;

class OrganizationService
{

    public function generateUserInviteUrl($email, $first_name, $last_name, $organizationId, $organizationUuid, $counselorId, $role, $counselor, $organization): string
    {
        
        return URL::temporarySignedRoute('register', now()->addDays(7), [
            'email' => $email,
            'first_name' => $first_name,
            'last_name' => $last_name,
            'role' => $role,
            'organization_id' => $organizationId,
            'organization_uuid' => $organizationUuid,
            'counselor_id' => $counselorId,
            'counselor_name' => $counselor->first_name . ' ' . $counselor->last_name,
            'organization_name' => $organization->name,
            'lang' => app()->getLocale()
        ]);
    }

    public function userEmailUnique($email): bool
    {
        $rule = new EncryptedEmailUniqueRule($email);
        return $rule->passes('email', $email);
    }

    public function userAlreadyPartOfOrganization($organizationId, $email): bool
    {
        $user = User::where('email', $email)->first();
        if (!$user) return false;

        return $user->organizations->contains($organizationId);
    }

    public function getDefaultKnowledgebaseCategoryTitlesByCountry(string $country): array
    {
        switch ($country) {
            case 'Germany':
            case 'Switzerland':
            case 'Austria':
                return ['Allgemein', 'Arbeitsrecht', 'Bewerbung', 'Beruf', 'Bildung', 'Gehalt', 'Jobsuchenden', 'Lernen'];
                break;
            case 'Italy':
                return ['Generale', 'Diritto del lavoro', 'Domanda', 'Professione', 'Educazione', 'Stipendio', 'Cercatori di lavoro', 'Apprendimento'];
                break;
            case 'Bulgaria':
                return ['Общ', 'Трудово право', 'Кандидатстване', 'Професия', 'Образование', 'Заплата', 'Търсещи работа', 'Учене'];
                break;
            default:
                return ['General', 'Labor Law', 'Application', 'Profession', 'Education', 'Salary', 'Job Seekers', 'Learning'];
                break;
        }
    }
}
