<?php

namespace App\Services;

use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Collection;
use Spatie\Permission\Models\Role;

class RoleService
{
    public function getAvailableRolesForUser(User $user): Collection
    {
        return Role::when($user->hasPermissionTo('publish_all_users') || $user->hasPermissionTo('publish_clients'), function ($query) {
            $query->where('name', 'client');
        })
        ->when($user->hasPermissionTo('publish_all_users'), function ($query) {
            $query->orWhere('name', 'organization-admin')
                ->orWhere('name', 'counselor');
        })
        ->select('id', 'name')
        ->get()
        ->map(function ($role) {
            return [
                'id'    => $role->id,
                'title' => ucfirst(str_replace('-', ' ', $role->name)),
                'value' => $role->name,
            ];
        });
    }
}
