<?php

namespace Database\Seeders;

use App\Models\CompetenceCard;
use App\Models\CompetenceCardCategory;
use Illuminate\Database\Seeder;
use phpDocumentor\Reflection\Types\Collection;

class CompetenceCardSeeder extends Seeder
{
    public function run(): void
    {
        $competence_card_categories = [
            [
                'title'             => 'Personal competence',
                'accent_color'      => 'rgba(74, 222, 128, 1)',
                'light_color'       => 'rgba(74, 222, 128, 0.15)',
            ],
            [
                'title'             => 'Social competence',
                'accent_color'      => 'rgba(251, 146, 60, 1)',
                'light_color'       => 'rgba(251, 146, 60, 0.15)',
            ],
            [
                'title'             => 'Methodological competence',
                'accent_color'      => 'rgba(29, 78, 216, 1)',
                'light_color'       => 'rgba(29, 78, 216, 0.15)',
            ],
            [
                'title'             => 'Professional competence',
                'accent_color'      => 'rgba(124, 58, 237, 1)',
                'light_color'       => 'rgba(124, 58, 237,0.15)',
            ],
            [
                'title'             => 'Digital competence',
                'accent_color'      => 'rgba(108, 229, 237, 1)',
                'light_color'       => 'rgba(108, 229, 237, 0.15)',
            ],
        ];

        $categories = collect([]);
        foreach ($competence_card_categories as $competence_card_category) {
            $categories->add(CompetenceCardCategory::create($competence_card_category));
        }

        $competence_cards = [
            [   'title'                     => 'Self-management',
                'description'               => 'I have a necessary degree of self-control and direction. I am able to apply integrity in practice.',
                'competence_card_category_id'    => $categories->where('title', 'Personal competence')->first()->id,
            ],
            [   'title'                     => 'Self-reflection',
                'description'               => 'I am able to reflect on my behaviours. I understand my own emotions and triggers. ',
                'competence_card_category_id'    => $categories->where('title', 'Personal competence')->first()->id,
            ],
            [   'title'                     => 'Self-awareness',
                'description'               => 'I am aware of my own strengths and learning areas. I am able to recognise my limits. I am in good contact with myself.',
                'competence_card_category_id'    => $categories->where('title', 'Personal competence')->first()->id,
            ],
            [   'title'                     => 'Self-responsibility',
                'description'               => 'I have self-confidence. I am able to take responsibility for my actions. I have the willingness to learn from my mistakes. ',
                'competence_card_category_id'    => $categories->where('title', 'Personal competence')->first()->id,
            ],
            [   'title'                     => 'Self-motivation',
                'description'               => 'I am able to develop intrinisic motivation. I am able to inspire myself for my tasks. ',
                'competence_card_category_id'    => $categories->where('title', 'Personal competence')->first()->id,
            ],
            [   'title'                     => 'Ability to learn',
                'description'               => '',
                'competence_card_category_id'    => $categories->where('title', 'Personal competence')->first()->id,
            ],
            [   'title'                     => 'Ability to work in a team',
                'description'               => 'I am able to promote inclusion. I am able to motivate different personalities. ',
                'competence_card_category_id'    => $categories->where('title', 'Social competence')->first()->id,
            ],
            [   'title'                     => 'Ability to cooperate',
                'description'               => 'I am able to work together with others. I have the skills to network with others. I am able to build partnerships. ',
                'competence_card_category_id'    => $categories->where('title', 'Social competence')->first()->id,
            ],
            [   'title'                     => 'Communication skills',
                'description'               => 'I can express myself well. I am able to listen actively. I am able to paraphrase content. I have diplomatic negotiation skills. ',
                'competence_card_category_id'    => $categories->where('title', 'Social competence')->first()->id,
            ],
            [   'title'                     => 'Ability to deal with conflict',
                'description'               => 'I am able to discuss conflicts in a solution-oriented way. I am familiar with the basics of escalation levels. I can apply non-violent communication. ',
                'competence_card_category_id'    => $categories->where('title', 'Social competence')->first()->id,
            ],
            [   'title'                     => 'Empathy',
                'description'               => 'I am able to empathise with others.',
                'competence_card_category_id'    => $categories->where('title', 'Social competence')->first()->id,
            ],
            [   'title'                     => 'Methodological competence',
                'description'               => 'I am able to acquire and utilise knowledge. I am able to deal with problems. I am able to proceed in a goal-oriented, structured and effective manner when working on tasks.',
                'competence_card_category_id'    => $categories->where('title', 'Methodological competence')->first()->id,
            ],

            [   'title'                     => 'Expert knowledge',
                'description'               => 'I have job-specific knowledge and skills. I have knowledge of facts and theories in a specific area. I am familiar with relevant terminology in a specific area',
                'competence_card_category_id'    => $categories->where('title', 'Professional competence')->first()->id,
            ],
            [   'title'                     => 'Information and data literacy',
                'description'               => 'I am able to articulate information needs, to locate and retrieve digital data, information and content. I am able to judge the relevance of the source and its content. I am able to store, managem, and organisae digital data, information and content',
                'competence_card_category_id'    => $categories->where('title', 'Digital competence')->first()->id,
            ],
            [   'title'                     => 'Communication and collaboration',
                'description'               => 'I am able to interact, communicate and collaborate through digital technologies while being aware of cultural and generational diversity. I am able to participate in society through public and private digital services and participation citizenship. I am able to manage one\'s digital presence, identy and reputation.',
                'competence_card_category_id'    => $categories->where('title', 'Digital competence')->first()->id,
            ],
            [   'title'                     => 'Digital content creation',
                'description'               => 'I am able to create and edit digital content. I am able to improve and integrate information and content into an existing body of knowledge while understanding how copyright and licences are to be applied. I am able to know how to give understandable instructions for a computer system. ',
                'competence_card_category_id'    => $categories->where('title', 'Digital competence')->first()->id,
            ],
            [   'title'                     => 'Safety',
                'description'               => 'I am able to protect devices, content, personal data and privacy in digital environments. I am able to protect physical and psychological health, and to be aware of digital technologies for social well-being and social inclusion. I am aware of the environmental impact of digital technologies and their use. ',
                'competence_card_category_id'    => $categories->where('title', 'Digital competence')->first()->id,
            ],
            [   'title'                     => 'Problem Solving',
                'description'               => 'I am able to identify needs and problems, and to resolve conceptual problems and problem situations in digital environments. I am able to use digital tools to innovate processes and products. I am able to keep up-to-date with the digital evolution. ',
                'competence_card_category_id'    => $categories->where('title', 'Digital competence')->first()->id,
            ],

        ];

        foreach ($competence_cards as $competence_card) {
            CompetenceCard::create($competence_card);
        }

    }
}
