<?php

namespace Database\Seeders;

use App\Events\ClientRegisteredEvent;
use App\Models\Organization;
use App\Models\User;
use Illuminate\Database\Seeder;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Spatie\Permission\Models\Role;

class CounselorTestUsersSeeder extends Seeder
{
    public function run(): void
    {
        $faker = \Faker\Factory::create();
        $file = fopen(storage_path('user_credentials.csv'), 'w');
        fputcsv($file, ['counselor ID', 'counselor Email', 'counselor Password', 'counselor login url', 'client ID', 'client Email', 'client Password']);
        $currentTimestamp = Carbon::now();
        $index = 16;
        $counselorRole = Role::where('name', 'counselor')->first();
        $clientRole = Role::where('name', 'client')->first();
        $organization = Organization::find(1);

        foreach (range(1, 60) as $i) {
            $counselorPassword = $this->generatePassword();
            $counselorEmail = "counselor" . $index . "@occay.eu";

            $counselor = User::create([
                'first_name' => $faker->firstName,
                'last_name' => $faker->lastName,
                'phone_number' => $faker->phoneNumber,
                'email' => $counselorEmail,
                'password' => Hash::make($counselorPassword),
                'current_organization_id' => $organization->id,
                'chat_disabled' => true,
                'privacy_tos_accepted' => $currentTimestamp,
                'email_verified_at' => $currentTimestamp,
                'is_active' => true,
            ]);

            $counselor->organizations()->attach($organization->id);
            $counselor->assignRole($counselorRole);
            $counselorLoginUrl = route('login', ['email' => $counselorEmail, 'pwd' => $counselorPassword, 'autologin' => 'true', 'locale' => 'de']);

            $clientPassword = $this->generatePassword();
            $clientEmail = "client" . $index . "@occay.eu";
            $client = User::create([
                'first_name' => $faker->firstName,
                'last_name' => $faker->lastName,
                'phone_number' => $faker->phoneNumber,
                'email' => $clientEmail,
                'password' => Hash::make($clientPassword),
                'current_organization_id' => $organization->id,
                'chat_disabled' => true,
                'privacy_tos_accepted' => $currentTimestamp,
                'email_verified_at' => $currentTimestamp,
                'is_active' => true,
                'counselor_id' => $counselor->id,
            ]);

            $client->organizations()->attach(1);
            $client->assignRole($clientRole);

            event(new ClientRegisteredEvent($organization, $client, $counselor, false));

            fputcsv($file, [$counselor->id, $counselorEmail, $counselorPassword, $counselorLoginUrl, $client->id, $clientEmail, $clientPassword]);
            $index++;
        }

        fclose($file);
    }

    private function generatePassword()
    {
        $upper = Str::upper(Str::random(1));
        $lower = Str::lower(Str::random(1));
        $special = Str::random(1, '!@#$%&*');
        $numbers = Str::random(1, '0123456789');
        $rest = Str::random(8);

        return $upper . $lower . $special . $numbers . $rest;
    }

}
