<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use Spatie\Permission\Models\Permission;
use Spatie\Permission\Models\Role;

class RolesAndPermissionsSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        // Reset cached roles and permissions
        app()[\Spatie\Permission\PermissionRegistrar::class]->forgetCachedPermissions();

        // create permissions

        Permission::create(['name' => 'view_organizations']);
        Permission::create(['name' => 'edit_organizations']);
        Permission::create(['name' => 'delete_organizations']);
        Permission::create(['name' => 'publish_organizations']);

        Permission::create(['name' => 'view_knowledgebase_articles']);
        Permission::create(['name' => 'edit_knowledgebase_articles']);
        Permission::create(['name' => 'delete_knowledgebase_articles']);
        Permission::create(['name' => 'publish_knowledgebase_articles']);

        Permission::create(['name' => 'view_knowledgebase_categories']);
        Permission::create(['name' => 'edit_knowledgebase_categories']);
        Permission::create(['name' => 'delete_knowledgebase_categories']);
        Permission::create(['name' => 'publish_knowledgebase_categories']);

        Permission::create(['name' => 'view_conversations']);
        Permission::create(['name' => 'edit_conversations']);
        Permission::create(['name' => 'delete_conversations']);
        Permission::create(['name' => 'publish_conversations']);

        Permission::create(['name' => 'view_conversation_assets']);
        Permission::create(['name' => 'edit_conversation_assets']);
        Permission::create(['name' => 'delete_conversation_assets']);
        Permission::create(['name' => 'publish_conversation_assets']);

        Permission::create(['name' => 'view_counselors']);
        Permission::create(['name' => 'edit_counselors']);
        Permission::create(['name' => 'delete_counselors']);
        Permission::create(['name' => 'publish_counselors']);

        Permission::create(['name' => 'view_clients']);
        Permission::create(['name' => 'edit_clients']);
        Permission::create(['name' => 'delete_clients']);
        Permission::create(['name' => 'publish_clients']);

        Permission::create(['name' => 'invite_clients']);
        Permission::create(['name' => 'invite_counselors']);

        Permission::create(['name' => 'view_appointments']);
        Permission::create(['name' => 'edit_appointments']);
        Permission::create(['name' => 'delete_appointments']);
        Permission::create(['name' => 'publish_appointments']);

        Permission::create(['name' => 'delete_conversation_files']);
        Permission::create(['name' => 'publish_conversation_files']);

        Permission::create(['name' => 'delete_conversation_notes']);
        Permission::create(['name' => 'publish_conversation_notes']);

        // Super Admin Permissions
        Permission::create(['name' => 'view_all_organizations']);
        Permission::create(['name' => 'edit_all_organizations']);
        Permission::create(['name' => 'delete_all_organizations']);
        Permission::create(['name' => 'publish_all_organizations']);

        Permission::create(['name' => 'view_all_users']);
        Permission::create(['name' => 'edit_all_users']);
        Permission::create(['name' => 'delete_all_users']);
        Permission::create(['name' => 'publish_all_users']);

        Permission::create(['name' => 'view_all_knowledgebase_articles']);
        Permission::create(['name' => 'edit_all_knowledgebase_articles']);
        Permission::create(['name' => 'delete_all_knowledgebase_articles']);
        Permission::create(['name' => 'publish_all_knowledgebase_articles']);

        Permission::create(['name' => 'view_all_conversations']);
        Permission::create(['name' => 'edit_all_conversations']);
        Permission::create(['name' => 'delete_all_conversations']);
        Permission::create(['name' => 'publish_all_conversations']);

        Permission::create(['name' => 'view_all_clients']);
        Permission::create(['name' => 'edit_all_clients']);
        Permission::create(['name' => 'delete_all_clients']);
        Permission::create(['name' => 'publish_all_clients']);

        Permission::create(['name' => 'view_all_appointments']);
        Permission::create(['name' => 'edit_all_appointments']);
        Permission::create(['name' => 'delete_all_appointments']);
        Permission::create(['name' => 'publish_all_appointments']);

        Permission::create(['name' => 'delete_all_conversation_files']);
        Permission::create(['name' => 'publish_all_conversation_files']);

        Permission::create(['name' => 'delete_all_conversation_notes']);
        Permission::create(['name' => 'publish_all_conversation_notes']);

        // create roles and assign created permissions

        // or may be done by chaining
        Role::create(['name' => 'organization-admin'])
            ->givePermissionTo([
                'view_organizations', 'edit_organizations',
                'view_knowledgebase_articles', 'edit_knowledgebase_articles', 'delete_knowledgebase_articles', 'publish_knowledgebase_articles',
                'view_knowledgebase_categories', 'edit_knowledgebase_categories', 'delete_knowledgebase_categories', 'publish_knowledgebase_categories',
                'view_appointments', 'edit_appointments', 'delete_appointments', 'publish_appointments',
                'view_conversations', 'edit_conversations', 'delete_conversations', 'publish_conversations',
                'view_clients', 'edit_clients', 'delete_clients', 'publish_clients',
                'view_counselors', 'edit_counselors', 'delete_counselors', 'publish_counselors',
                'view_conversation_assets', 'edit_conversation_assets', 'delete_conversation_assets', 'publish_conversation_assets',
                'invite_counselors', 'invite_clients',
                'view_all_users', 'edit_all_users', 'delete_all_users', 'publish_all_users',
                'view_all_knowledgebase_articles', 'edit_all_knowledgebase_articles', 'delete_all_knowledgebase_articles', 'publish_all_knowledgebase_articles',
                'view_all_conversations', 'edit_all_conversations', 'delete_all_conversations', 'publish_all_conversations',
                'view_all_clients', 'edit_all_clients', 'delete_all_clients', 'publish_all_clients',
                'view_all_appointments', 'edit_all_appointments', 'delete_all_appointments', 'publish_all_appointments',
                'delete_conversation_files', 'publish_conversation_files', 'delete_all_conversation_files', 'publish_all_conversation_files',
                'delete_conversation_notes', 'publish_conversation_notes', 'delete_all_conversation_notes', 'publish_all_conversation_notes',
            ]);

        Role::create(['name' => 'counselor'])
            ->givePermissionTo(['view_knowledgebase_articles', 'edit_knowledgebase_articles', 'publish_knowledgebase_articles',
                'view_knowledgebase_categories', 'edit_knowledgebase_categories', 'publish_knowledgebase_categories',
                'view_conversations', 'publish_conversations', 'edit_conversations', 'delete_conversations',
                'view_appointments', 'edit_appointments', 'delete_appointments', 'publish_appointments',
                'view_clients', 'edit_clients', 'delete_clients', 'publish_clients',
                'view_conversation_assets', 'edit_conversation_assets', 'delete_conversation_assets', 'publish_conversation_assets',
                'delete_conversation_files', 'publish_conversation_files',
                'invite_clients',
                'delete_conversation_notes', 'publish_conversation_notes',
            ]);

        Role::create(['name' => 'client'])
            ->givePermissionTo([
                'view_knowledgebase_articles',
                'view_conversations',
                'view_appointments', 'edit_appointments', 'delete_appointments', 'publish_appointments',
                'view_conversation_assets', 'edit_conversation_assets',
                'delete_conversation_files', 'publish_conversation_files',
            ]);

        $role = Role::create(['name' => 'super-admin']);
        $role->givePermissionTo(Permission::all());
    }
}
