import {defineStore} from "pinia";
import {AcademicCapIcon, BriefcaseIcon, CalendarIcon, MapPinIcon} from "@heroicons/vue/24/outline";

export const useTimelineItemsStore = defineStore('timelineItems', {
    state: () => ({
        items: [],
        showCreateTimelineItemModal: false,
        highlightedTimelineItem: null,
        timelineItemScrollTo: null,
        showTimelineItemDetails: false,
        timelineItemTypes: [
            {
                id: 'education',
                icon: AcademicCapIcon,
                title: 'Education'
            },
            {
                id: 'work',
                icon: BriefcaseIcon,
                title: 'Work'
            },
            {
                id: 'private_life',
                icon: CalendarIcon,
                title: 'Private Life'
            },
            {
                id: 'other',
                icon: MapPinIcon,
                title: 'Other'
            }
        ],
        timlineItemToEdit: null,
    }),
    actions: {
        setTimelineItems(items) {
            this.items = items;
        },
        setShowTimelineItemDetails(show) {
            this.showTimelineItemDetails = show;
        },
        setShowCreateTimelineItemModal(show) {
            this.showCreateTimelineItemModal = show;
        },
        setTimelineItemScrollTo(item) {
            this.timelineItemScrollTo = item;
        },
        setHighlightedTimelineItem(item) {
            this.highlightedTimelineItem = item;
        },
        addTimelineItem(item) {
            this.items.push(item);
        },
        removeTimelineItem(item_id) {
            let i = this.items.findIndex(i => i.id === item_id);
            this.items.splice(i, 1);
        },
        replaceTimelineItem(item) {
            let i = this.items.findIndex(i => i.id === item.id);
            this.items.splice(i, 1, item);
        },
        lockTimelineItem(item) {
            this.items.find(i => i.id === item.id).is_locked_by = item.is_locked_by;
        },
        setTimelineItemToEdit(item) {
            this.timlineItemToEdit = item;
        }
    },
    getters: {
        sortedItems(state) {
            if (!state.items) {
                return [];
            }
            return state.items.sort((a, b) => {
                return a.date - b.date;
            });
        },

    }
});
