import {i18nVue} from "laravel-vue-i18n";
import {createApp, h} from 'vue';
import {createInertiaApp, Head, Link} from '@inertiajs/inertia-vue3';
import {InertiaProgress} from '@inertiajs/progress';
import AuthenticatedOrganization from "@/Layouts/AuthenticatedOrganization";
import LaravelPermissionToVueJS from "../../vendor/zodexnl/spatie-permission-to-vue-inertia/src/js";

import {createPinia} from "pinia";

// Localization
//import {createI18n} from 'vue-i18n';
// SweetAlert2
import VueSweetalert2 from "vue-sweetalert2";

// Media Library
import {MediaLibraryAttachment} from "media-library-pro-vue3-attachment";
import {MediaLibraryCollection} from "media-library-pro-vue3-collection";

// Editor
import CKEditor from '@ckeditor/ckeditor5-vue';

import Panzoom from "@panzoom/panzoom";

import Permissions from "@/Composables/usePermissions";

// Moment.js
import moment from "moment";

// FullCalendar
import FullCalendar from "@fullcalendar/vue3";

require('./bootstrap');

const el = document.getElementById('app');

InertiaProgress.init({color: '#3730a3'});

createInertiaApp({
    resolve: (name) => {
        let page = require(`./Pages/${name}`).default;

        if (page.layout === undefined) {
            page.layout = AuthenticatedOrganization;
        }

        return page;
    },
    setup({el, app, props, plugin}) {

        return createApp({render: () => h(app, props)})
            .mixin({methods: {route}})
            .use(plugin)
            .use(i18nVue, {
                lang: localStorage.getItem('locale'),
                resolve: lang => import('../../resources/lang/' + lang + '.json'),
            })
            .use(createPinia())
            .use(VueSweetalert2)
            .use(LaravelPermissionToVueJS)
            .use(CKEditor)
            .use(MediaLibraryAttachment)
            .use(MediaLibraryCollection)
            .use(moment)
            .mixin(Panzoom)
            .mixin(Permissions)
            .use(FullCalendar)
            .component("Head", Head)
            .component("Link", Link)
            .mount(el);
    },
    title: title => "OCCAY App: " + title,
});

