<?php

use App\Http\Controllers\AppointmentController;
use App\Http\Controllers\Auth\UpdateUserController;
use App\Http\Controllers\ClientController;
use App\Http\Controllers\ConversationAssetController;
use App\Http\Controllers\ConversationController;
use App\Http\Controllers\ConversationNoteController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\EmployeeController;
use App\Http\Controllers\KnowledgebaseArticleController;
use App\Http\Controllers\KnowledgebaseCategoryController;
use App\Http\Controllers\LanguageController;
use App\Http\Controllers\MediaController;
use App\Http\Controllers\MessageController;
use App\Http\Controllers\OrganizationController;
use App\Http\Controllers\RegistrationController;
use App\Http\Controllers\TimelineItemController;
use App\Http\Controllers\UserController;
use Illuminate\Support\Facades\Route;
use Inertia\Inertia;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/


Route::middleware('set_locale')->group(function () {
    // PUBLIC PAGES
    Route::get('/', function () {
        return Inertia::render('Home/Home');
    })->name('home');

    Route::get('/privacy', function () {
        return Inertia::render('Home/Privacy');
    })->name('privacy');

    Route::get('/terms-of-service', function () {
        return Inertia::render('Home/TermsOfService');
    })->name('terms');

    Route::get('/imprint', function () {
        return Inertia::render('Home/Imprint');
    })->name('imprint');

    Route::get('/organization-tutorial', function () {
        return Inertia::render('Home/OrganizationAdminTutorial');
    })->name('organization.tutorial');

// LANGUAGE SWITCHER
    Route::post('language/{locale}', LanguageController::class)->name('switch_language');

// REGISTER ORGANIZATION
    Route::get('/register/organization', [RegistrationController::class, 'create'])
        ->middleware('guest')
        ->name('register.organization.create');
    Route::post('/register/organization', [RegistrationController::class, 'store'])
        ->middleware('guest')
        ->name('register.organization.store');

    Route::middleware(['auth', 'counselor_verified_email', 'organization'])->group(function () {

        Route::get('/dashboard', [DashboardController::class, 'show'])
            ->name('organization.dashboard');

        Route::get('/dashboard/testroom', [DashboardController::class, 'show_testroom'])
            ->name('organization.dashboard.testroom');

        Route::post('/organization/{organization}/invite', [OrganizationController::class, 'inviteUser'])
            ->middleware(['permission:invite_clients|invite_counselors'])
            ->name('organization.invite');

        // JOIN / CHANGE ORGANIZATIONS
        Route::post('organizations/{organization}/join', [OrganizationController::class, 'join_organization'])
            ->middleware(['role:super-admin'])
            ->name('organization.join');

        Route::post('organizations/{organization}/change', [OrganizationController::class, 'change_organization'])
            ->middleware(['role:super-admin'])
            ->name('organization.change');

        // ORGANIZATION
        Route::resource('organizations', OrganizationController::class)
            ->middleware(['auth', 'counselor_verified_email', 'permission:view_all_organizations|view_organizations', 'organization']);

        // USERS
        Route::put('/organizations/{organization}/users/{user}/update', [UpdateUserController::class, 'update'])
            ->middleware('permission:edit_clients|edit_counselors|edit_all_users')
            ->name('organizations.users.update');
        Route::get('/organizations/{organization}/users/create', [UserController::class, 'create'])
            ->middleware('permission:publish_clients|publish_counselors|publish_all_users')
            ->name('organizations.users.create');
        Route::post('/organizations/{organization}/users', [UserController::class, 'store'])
            ->middleware('permission:publish_clients|publish_counselors|publish_all_users')
            ->name('organizations.users.store');

        // USER PROFILE
        Route::get('/organizations/{organization}/profile/{user}', [UserController::class, 'edit'])
            ->middleware('edit_profile')
            ->name('organizations.users.profile');
        Route::put('/organizations/{organization}/profile/{user}/update', [UserController::class, 'update_profile'])
            ->middleware('edit_profile')
            ->name('organizations.users.update_profile');
        Route::put('/organizations/{organization}/profile/{user}/password', [UserController::class, 'update_password'])
            ->middleware('edit_profile')
            ->name('organizations.users.update_password');

        // EMPLOYEES/COUNSELORS
        Route::get('/organizations/{organization}/employees/{user}', [EmployeeController::class, 'show'])
            ->middleware('permission:view_counselors|view_all_counselors')
            ->name('organizations.employees.show');
        Route::get('/organizations/{organization}/employees/{user}/edit', [EmployeeController::class, 'edit'])
            ->middleware('permission:edit_counselors|edit_all_counselors')
            ->name('organizations.employees.edit');
        Route::delete('/organizations/{organization}/employees/{user}/destroy', [EmployeeController::class, 'destroy'])
            ->middleware('permission:delete_counselors|delete_all_counselors')
            ->name('organizations.employees.destroy');

        // CLIENTS
        Route::get('/organizations/{organization}/clients', [ClientController::class, 'index'])
            ->middleware('permission:view_clients|view_all_clients')
            ->name('organizations.clients.index');
        Route::get('/organizations/{organization}/clients/{user}', [ClientController::class, 'show'])
            ->middleware('permission:view_clients|view_all_clients')
            ->name('organizations.clients.show');
        Route::get('/organizations/{organization}/clients/{user}/edit', [ClientController::class, 'edit'])
            ->middleware('permission:edit_clients|edit_all_clients')
            ->name('organizations.clients.edit');
        Route::delete('/organizations/{organization}/clients/{user}/destroy', [ClientController::class, 'destroy'])
            ->middleware('permission:delete_clients|delete_all_clients')
            ->name('organizations.clients.destroy');
        Route::put('/organizations/{organization}/clients/{user}/counselor/{counselor}', [ClientController::class, 'change_counselor'])
            ->middleware('permission:edit_clients|edit_all_clients')
            ->name('organizations.clients.change_counselor');

        // RESOURCE KNOWLEDGEBASE
        Route::resource('organizations.knowledgebase_articles', KnowledgebaseArticleController::class);

        Route::resource('organizations.knowledgebase_categories', KnowledgebaseCategoryController::class)
            ->middleware(['permission:edit_knowledgebase_categories|edit_all_knowledgebase_categories']);

        // TODO CONVERSATION ASSETS
        Route::get('/organizations/{organization}/conversations/{conversation}/conversation_assets/{conversation_asset}/invite', [ConversationAssetController::class, 'inviteToConversationAsset'])->name('organizations.conversations.conversation_assets.invite');
        Route::put('/organizations/{organization}/conversations/{conversation}/conversation_assets/{conversation_asset}/update_competence_card_set', [ConversationAssetController::class, 'updateCompetenceCardSet'])->name('organizations.conversations.conversation_assets.update_competence_card_set');
        Route::Resource('organizations.conversations.conversation_assets', ConversationAssetController::class);

        // TODO TIMELINE ITEMS
        Route::put('/organizations/{organization}/conversations/{conversation}/conversation_assets/{conversation_asset}/timeline_items/{timeline_item}/lock', [TimelineItemController::class, 'lock'])
            ->name('organizations.conversations.conversation_assets.timeline_items.lock');
        Route::Resource('organizations.conversations.conversation_assets.timeline_items', TimelineItemController::class);

        // MESSAGES
        Route::post('/organizations/{organization}/conversations/{conversation}/messages', [MessageController::class, 'sendMessage'])
            ->middleware(['permission:view_all_conversations|view_conversations', 'conversation_belongs_to_user'])
            ->name('organizations.conversations.messages.send');

        Route::Resource('organizations.conversations.conversation_notes', ConversationNoteController::class)->only(['index', 'store', 'update', 'destroy'])->middleware('permission:delete_conversation_notes|publish_conversation_notes|delete_all_conversation_notes|publish_all_conversation_notes');

        // CONVERSATIONS
        Route::put('/organizations/{organization}/conversations/{conversation}/knowledgebase_article/{knowledgebase_article}/attach', [ConversationController::class, 'attach_knowldegebase_article'])
            ->middleware(['permission:edit_all_conversations|edit_conversations', 'conversation_belongs_to_user'])
            ->name('organizations.conversations.knowledgebase_article.attach');
        Route::put('/organizations/{organization}/conversations/{conversation}/knowledgebase_article/{knowledgebase_article}/detach', [ConversationController::class, 'detach_knowledgebase_article'])
            ->middleware(['permission:edit_all_conversations|edit_conversations', 'conversation_belongs_to_user'])
            ->name('organizations.conversations.knowledgebase_article.detach');

        Route::put('/organizations/{organization}/conversations/{conversation}/add_media', [ConversationController::class, 'add_media'])
            ->middleware(['permission:publish_conversation_files|publish_all_conversation_files', 'conversation_belongs_to_user'])
            ->name('organizations.conversations.add_media');
        Route::delete('/organizations/{organization}/conversations/{conversation}/remove_media', [ConversationController::class, 'remove_media'])
            ->middleware(['permission:delete_conversation_files|delete_all_conversation_files', 'conversation_belongs_to_user'])
            ->name('organizations.conversations.remove_media');

        Route::get('/organizations/{organization}/conversations', [ConversationController::class, 'index'])
            ->middleware(['permission:view_all_conversations|view_conversations'])
            ->name('organizations.conversations.index');
        Route::get('/organizations/{organization}/conversations/{conversation}/{conversation_asset?}', [ConversationController::class, 'show'])
            ->middleware(['permission:view_all_conversations|view_conversations', 'conversation_belongs_to_user'])
            ->name('organizations.conversations.show');
        Route::get('/organizations/{organization}/conversations/{conversation}/destroy', [ConversationController::class, 'destroy'])
            ->middleware('permission:delete_conversations|delete_all_conversations, conversation_belongs_to_user')
            ->name('organizations.conversations.destroy');


        // APPOINTMENTS
        Route::get('/organizations/{organization}/appointments/{appointment?}', [AppointmentController::class, 'index'])->name('organizations.appointments.index');
        Route::resource('organizations.appointments', AppointmentController::class)->except(['index']);

        Route::get('/dashboard/settings', [OrganizationController::class, 'settings'])->middleware('role:organization-admin|super-admin')->name('app.settings');

        Route::group(['middleware' => ['role:super-admin']], function () {
            // Competence Cards
            Route::get('/dashboard/settings/competence-cards', [\App\Http\Controllers\CompetenceCardController::class, 'index'])->name('app.settings.competence_cards.index');
            Route::get('/dashboard/settings/competence-cards/{competence_card}/edit', [\App\Http\Controllers\CompetenceCardController::class, 'edit'])->name('app.settings.competence_cards.edit');
            Route::put('/dashboard/settings/competence-cards/{competence_card}', [\App\Http\Controllers\CompetenceCardController::class, 'update'])->name('app.settings.competence_cards.update');
            Route::delete('/dashboard/settings/competence-cards/{competence_card}/destroy', [\App\Http\Controllers\CompetenceCardController::class, 'destroy'])->name('app.settings.competence_cards.destroy');

            // Comptence Card Categories
            Route::get('/dashboard/settings/competence-card-categories', [\App\Http\Controllers\CompetenceCardCategoryController::class, 'index'])->name('app.settings.competence_card_categories.index');
            Route::get('/dashboard/settings/competence-card-categories/{competence_card_category}/edit', [\App\Http\Controllers\CompetenceCardCategoryController::class, 'edit'])->name('app.settings.competence_card_categories.edit');
            Route::put('/dashboard/settings/competence-card-categories/{competence_card_category}', [\App\Http\Controllers\CompetenceCardCategoryController::class, 'update'])->name('app.settings.competence_card_categories.update');
            Route::delete('/dashboard/settings/competence-card-categories/{competence_card_category}/destroy', [\App\Http\Controllers\CompetenceCardCategoryController::class, 'destroy'])->name('app.settings.competence_card_categories.destroy');
        });


    });

    Route::get('/uploads/{mediaId}', [MediaController::class, 'getPublicMedia'])->name('publicMedia');

// USER MEDIA
    Route::middleware('auth')->group(function () {
        Route::get('/uploads/{organization}/{mediaId}/{fileName}', [MediaController::class, 'getUserMedia'])->name('userMedia');
        Route::mediaLibrary();
    });

    require __DIR__ . '/auth.php';
});
